==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/EnvironmentvariablevalueCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Environmentvariablevalue;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.EnvironmentvariablevalueRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class EnvironmentvariablevalueCollectionRequest extends CollectionPageEntityRequest<Environmentvariablevalue, EnvironmentvariablevalueRequest>{

    protected ContextPath contextPath;

    public EnvironmentvariablevalueCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Environmentvariablevalue.class, cp -> new EnvironmentvariablevalueRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest environmentvariablevalue_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("environmentvariablevalue_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest environmentvariablevalue_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("environmentvariablevalue_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariablevalue_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("environmentvariablevalue_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariablevalue_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariablevalue_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariablevalue_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("environmentvariablevalue_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariablevalue_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariablevalue_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest environmentvariablevalue_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("environmentvariablevalue_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest environmentvariablevalue_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("environmentvariablevalue_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest environmentvariablevalue_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("environmentvariablevalue_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest environmentvariablevalue_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("environmentvariablevalue_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest environmentvariablevalue_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("environmentvariablevalue_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest environmentvariablevalue_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("environmentvariablevalue_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest environmentvariablevalue_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("environmentvariablevalue_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest environmentvariablevalue_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("environmentvariablevalue_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest environmentvariablevalue_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("environmentvariablevalue_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest environmentvariablevalue_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("environmentvariablevalue_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/EnvironmentvariablevalueCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Environmentvariablevalue;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.EnvironmentvariablevalueRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class EnvironmentvariablevalueCollectionRequest extends CollectionPageEntityRequest<Environmentvariablevalue, EnvironmentvariablevalueRequest>{

    protected ContextPath contextPath;

    public EnvironmentvariablevalueCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Environmentvariablevalue.class, cp -> new EnvironmentvariablevalueRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest environmentvariablevalue_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("environmentvariablevalue_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest environmentvariablevalue_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("environmentvariablevalue_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariablevalue_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("environmentvariablevalue_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariablevalue_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariablevalue_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariablevalue_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("environmentvariablevalue_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariablevalue_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariablevalue_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest environmentvariablevalue_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("environmentvariablevalue_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest environmentvariablevalue_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("environmentvariablevalue_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest environmentvariablevalue_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("environmentvariablevalue_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest environmentvariablevalue_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("environmentvariablevalue_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest environmentvariablevalue_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("environmentvariablevalue_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest environmentvariablevalue_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("environmentvariablevalue_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest environmentvariablevalue_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("environmentvariablevalue_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest environmentvariablevalue_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("environmentvariablevalue_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest environmentvariablevalue_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("environmentvariablevalue_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest environmentvariablevalue_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("environmentvariablevalue_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}
